@@ -14,13 +14,20 @@
  *
  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
  */
 
 #include <babeltrace/ctf-text/types.h>
 #include <babeltrace/format.h>
 #include <babeltrace/babeltrace-internal.h>
 #include <inttypes.h>
-#include <uuid/uuid.h>
 #include <sys/mman.h>
 #include <errno.h>
 #include <sys/types.h>
@@ -32,34 +39,37 @@
 #include <stdlib.h>
 
 static
-int bt_dummy_write_event(struct stream_pos *ppos,
-			 struct ctf_stream *stream)
+int bt_dummy_write_event(struct bt_stream_pos *ppos, struct ctf_stream_definition *stream)
 {
 	return 0;
 }
 
 static
-struct trace_descriptor *bt_dummy_open_trace(const char *path, int flags)
+struct bt_trace_descriptor *bt_dummy_open_trace(const char *path, int flags,
+		void (*packet_seek)(struct bt_stream_pos *pos, size_t index,
+			int whence), FILE *metadata_fp)
 {
 	struct ctf_text_stream_pos *pos;
 
 	pos = g_new0(struct ctf_text_stream_pos, 1);
 	pos->parent.rw_table = NULL;
 	pos->parent.event_cb = bt_dummy_write_event;
+	pos->parent.trace = &pos->trace_descriptor;
 	return &pos->trace_descriptor;
 }
 
 static
-void bt_dummy_close_trace(struct trace_descriptor *td)
+int bt_dummy_close_trace(struct bt_trace_descriptor *td)
 {
 	struct ctf_text_stream_pos *pos =
 		container_of(td, struct ctf_text_stream_pos,
 			trace_descriptor);
 	free(pos);
+	return 0;
 }
 
 static
-struct format bt_dummy_format = {
+struct bt_format bt_dummy_format = {
 	.open_trace = bt_dummy_open_trace,
 	.close_trace = bt_dummy_close_trace,
 };
@@ -74,4 +84,8 @@ void __attribute__((constructor)) bt_dummy_init(void)
 	assert(!ret);
 }
 
-/* TODO: finalize */
+static
+void __attribute__((destructor)) bt_dummy_exit(void)
+{
+	bt_unregister_format(&bt_dummy_format);
+}
