@@ -90,12 +90,12 @@ int setup_sighandler(void)
 }
 
 /*
- * hostname parameter needs to hold NAME_MAX chars.
+ * hostname parameter needs to hold MAXNAMLEN chars.
  */
 static
 int parse_url(const char *path, struct lttng_live_ctx *ctx)
 {
-	char remain[3][NAME_MAX];
+	char remain[3][MAXNAMLEN];
 	int ret = -1, proto, proto_offset = 0;
 	size_t path_len = strlen(path);	/* not accounting \0 */
 
@@ -104,7 +104,7 @@ int parse_url(const char *path, struct lttng_live_ctx *ctx)
 	 * against a size defined by a macro. Test it beforehand on the
 	 * input. We know the output is always <= than the input length.
 	 */
-	if (path_len >= NAME_MAX) {
+	if (path_len >= MAXNAMLEN) {
 		goto end;
 	}
 	ret = sscanf(path, "net%d://", &proto);
@@ -187,6 +187,30 @@ end:
 	return ret;
 }
 
+static
+guint g_uint64p_hash(gconstpointer key)
+{
+	uint64_t v = *(uint64_t *) key;
+
+	if (sizeof(gconstpointer) == sizeof(uint64_t)) {
+		return g_direct_hash((gconstpointer) (unsigned long) v);
+	} else {
+		return g_direct_hash((gconstpointer) (unsigned long) (v >> 32))
+			^ g_direct_hash((gconstpointer) (unsigned long) v);
+	}
+}
+
+static
+gboolean g_uint64p_equal(gconstpointer a, gconstpointer b)
+{
+	uint64_t va = *(uint64_t *) a;
+	uint64_t vb = *(uint64_t *) b;
+
+	if (va != vb)
+		return FALSE;
+	return TRUE;
+}
+
 static int lttng_live_open_trace_read(const char *path)
 {
 	int ret = 0;
@@ -199,8 +223,8 @@ static int lttng_live_open_trace_read(const char *path)
 	ctx->session->ctx = ctx;
 
 	/* HT to store the CTF traces. */
-	ctx->session->ctf_traces = g_hash_table_new(g_direct_hash,
-			g_direct_equal);
+	ctx->session->ctf_traces = g_hash_table_new(g_uint64p_hash,
+			g_uint64p_equal);
 	ctx->port = -1;
 	ctx->session_ids = g_array_new(FALSE, TRUE, sizeof(uint64_t));
 
