@@ -16,21 +16,30 @@
  *
  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
  */
 
 #include <babeltrace/compiler.h>
 #include <babeltrace/format.h>
+#include <babeltrace/types.h>
 #include <inttypes.h>
 
 static
-struct definition *_sequence_definition_new(struct declaration *declaration,
+struct bt_definition *_sequence_definition_new(struct bt_declaration *declaration,
 					struct definition_scope *parent_scope,
 					GQuark field_name, int index,
 					const char *root_name);
 static
-void _sequence_definition_free(struct definition *definition);
+void _sequence_definition_free(struct bt_definition *definition);
 
-int sequence_rw(struct stream_pos *pos, struct definition *definition)
+int bt_sequence_rw(struct bt_stream_pos *pos, struct bt_definition *definition)
 {
 	struct definition_sequence *sequence_definition =
 		container_of(definition, struct definition_sequence, p);
@@ -53,19 +62,24 @@ int sequence_rw(struct stream_pos *pos, struct definition *definition)
 		g_ptr_array_set_size(sequence_definition->elems, len);
 
 	for (i = oldlen; i < len; i++) {
-		struct definition **field;
+		struct bt_definition **field;
 		GString *str;
 		GQuark name;
 
 		str = g_string_new("");
 		g_string_printf(str, "[%" PRIu64 "]", i);
-		(void) g_string_free(str, TRUE);
 		name = g_quark_from_string(str->str);
+		(void) g_string_free(str, TRUE);
 
-		field = (struct definition **) &g_ptr_array_index(sequence_definition->elems, i);
+		field = (struct bt_definition **) &g_ptr_array_index(sequence_definition->elems, i);
 		*field = sequence_declaration->elem->definition_new(sequence_declaration->elem,
 					  sequence_definition->p.scope,
 					  name, i, NULL);
+	}
+	for (i = 0; i < len; i++) {
+		struct bt_definition **field;
+
+		field = (struct bt_definition **) &g_ptr_array_index(sequence_definition->elems, i);
 		ret = generic_rw(pos, *field);
 		if (ret)
 			return ret;
@@ -74,34 +88,34 @@ int sequence_rw(struct stream_pos *pos, struct definition *definition)
 }
 
 static
-void _sequence_declaration_free(struct declaration *declaration)
+void _sequence_declaration_free(struct bt_declaration *declaration)
 {
 	struct declaration_sequence *sequence_declaration =
 		container_of(declaration, struct declaration_sequence, p);
 
-	free_declaration_scope(sequence_declaration->scope);
+	bt_free_declaration_scope(sequence_declaration->scope);
 	g_array_free(sequence_declaration->length_name, TRUE);
-	declaration_unref(sequence_declaration->elem);
+	bt_declaration_unref(sequence_declaration->elem);
 	g_free(sequence_declaration);
 }
 
 struct declaration_sequence *
-	sequence_declaration_new(const char *length,
-			  struct declaration *elem_declaration,
+	bt_sequence_declaration_new(const char *length,
+			  struct bt_declaration *elem_declaration,
 			  struct declaration_scope *parent_scope)
 {
 	struct declaration_sequence *sequence_declaration;
-	struct declaration *declaration;
+	struct bt_declaration *declaration;
 
 	sequence_declaration = g_new(struct declaration_sequence, 1);
 	declaration = &sequence_declaration->p;
 
 	sequence_declaration->length_name = g_array_new(FALSE, TRUE, sizeof(GQuark));
-	append_scope_path(length, sequence_declaration->length_name);
+	bt_append_scope_path(length, sequence_declaration->length_name);
 
-	declaration_ref(elem_declaration);
+	bt_declaration_ref(elem_declaration);
 	sequence_declaration->elem = elem_declaration;
-	sequence_declaration->scope = new_declaration_scope(parent_scope);
+	sequence_declaration->scope = bt_new_declaration_scope(parent_scope);
 	declaration->id = CTF_TYPE_SEQUENCE;
 	declaration->alignment = elem_declaration->alignment;
 	declaration->declaration_free = _sequence_declaration_free;
@@ -112,7 +126,7 @@ struct declaration_sequence *
 }
 
 static
-struct definition *_sequence_definition_new(struct declaration *declaration,
+struct bt_definition *_sequence_definition_new(struct bt_declaration *declaration,
 				struct definition_scope *parent_scope,
 				GQuark field_name, int index,
 				const char *root_name)
@@ -120,11 +134,11 @@ struct definition *_sequence_definition_new(struct declaration *declaration,
 	struct declaration_sequence *sequence_declaration =
 		container_of(declaration, struct declaration_sequence, p);
 	struct definition_sequence *sequence;
-	struct definition *len_parent;
+	struct bt_definition *len_parent;
 	int ret;
 
 	sequence = g_new(struct definition_sequence, 1);
-	declaration_ref(&sequence_declaration->p);
+	bt_declaration_ref(&sequence_declaration->p);
 	sequence->p.declaration = declaration;
 	sequence->declaration = sequence_declaration;
 	sequence->p.ref = 1;
@@ -134,12 +148,12 @@ struct definition *_sequence_definition_new(struct declaration *declaration,
 	 */
 	sequence->p.index = root_name ? INT_MAX : index;
 	sequence->p.name = field_name;
-	sequence->p.path = new_definition_path(parent_scope, field_name, root_name);
-	sequence->p.scope = new_definition_scope(parent_scope, field_name, root_name);
-	ret = register_field_definition(field_name, &sequence->p,
+	sequence->p.path = bt_new_definition_path(parent_scope, field_name, root_name);
+	sequence->p.scope = bt_new_definition_scope(parent_scope, field_name, root_name);
+	ret = bt_register_field_definition(field_name, &sequence->p,
 					parent_scope);
 	assert(!ret);
-	len_parent = lookup_path_definition(sequence->p.scope->scope_path,
+	len_parent = bt_lookup_path_definition(sequence->p.scope->scope_path,
 					    sequence_declaration->length_name,
 					    parent_scope);
 	if (!len_parent) {
@@ -152,7 +166,7 @@ struct definition *_sequence_definition_new(struct declaration *declaration,
 		printf("[error] Sequence length field should be unsigned.\n");
 		goto error;
 	}
-	definition_ref(len_parent);
+	bt_definition_ref(len_parent);
 
 	sequence->string = NULL;
 	sequence->elems = NULL;
@@ -177,43 +191,43 @@ struct definition *_sequence_definition_new(struct declaration *declaration,
 	return &sequence->p;
 
 error:
-	free_definition_scope(sequence->p.scope);
-	declaration_unref(&sequence_declaration->p);
+	bt_free_definition_scope(sequence->p.scope);
+	bt_declaration_unref(&sequence_declaration->p);
 	g_free(sequence);
 	return NULL;
 }
 
 static
-void _sequence_definition_free(struct definition *definition)
+void _sequence_definition_free(struct bt_definition *definition)
 {
 	struct definition_sequence *sequence =
 		container_of(definition, struct definition_sequence, p);
-	struct definition *len_definition = &sequence->length->p;
+	struct bt_definition *len_definition = &sequence->length->p;
 	uint64_t i;
 
 	if (sequence->string)
 		(void) g_string_free(sequence->string, TRUE);
 	if (sequence->elems) {
 		for (i = 0; i < sequence->elems->len; i++) {
-			struct definition *field;
+			struct bt_definition *field;
 
 			field = g_ptr_array_index(sequence->elems, i);
 			field->declaration->definition_free(field);
 		}
+		(void) g_ptr_array_free(sequence->elems, TRUE);
 	}
-	(void) g_ptr_array_free(sequence->elems, TRUE);
-	definition_unref(len_definition);
-	free_definition_scope(sequence->p.scope);
-	declaration_unref(sequence->p.declaration);
+	bt_definition_unref(len_definition);
+	bt_free_definition_scope(sequence->p.scope);
+	bt_declaration_unref(sequence->p.declaration);
 	g_free(sequence);
 }
 
-uint64_t sequence_len(struct definition_sequence *sequence)
+uint64_t bt_sequence_len(struct definition_sequence *sequence)
 {
 	return sequence->length->value._unsigned;
 }
 
-struct definition *sequence_index(struct definition_sequence *sequence, uint64_t i)
+struct bt_definition *bt_sequence_index(struct definition_sequence *sequence, uint64_t i)
 {
 	if (!sequence->elems)
 		return NULL;
